ActionResponse enum

Result of a call to enableBluetooth or disableBluetooth.

Inheritance
Available extensions

Values

bluetoothIsOn → const ActionResponse

Android: the adapter was turned on by this call.

bluetoothIsOff → const ActionResponse

Android: the adapter was turned off by this call.

bluetoothAlreadyOn → const ActionResponse

Android: the adapter was already on.

bluetoothAlreadyOff → const ActionResponse

Android: the adapter was already off.

responseError → const ActionResponse

The native side returned an error (unsupported SDK, missing permission, Android 13+ where the API is deprecated, etc.).

openedIOSSettings → const ActionResponse

iOS: the plugin opened the system Bluetooth settings screen so the user can toggle the adapter manually.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ActionResponse>
A constant List of the values in this enum, in order of their declaration.