BluetoothState enum
Represents the current state of the device's Bluetooth adapter.
Values
- on → const BluetoothState
-
The Bluetooth adapter is turned on.
- off → const BluetoothState
-
The Bluetooth adapter is turned off.
- uknow → const BluetoothState
-
The state could not be determined (permission denied, unsupported hardware, transient native error, etc.).
Note: this value is intentionally spelled
uknow(without the "n") for backwards compatibility with older releases of the plugin.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BluetoothState> - A constant List of the values in this enum, in order of their declaration.